import type { PrimitiveTypes } from '@servequery/datasource-toolkit';
export type ServequerySchema = {
    collections: ServequeryServerCollection[];
    meta: {
        liana: string;
        liana_version: string;
        liana_features: Record<string, string> | null;
        stack: {
            engine: string;
            engine_version: string;
        };
    };
};
export type ServequeryServerColumnType = PrimitiveTypes | [ServequeryServerColumnType] | {
    fields: Array<{
        field: string;
        type: ServequeryServerColumnType;
    }>;
};
export type ServequeryServerCollection = {
    name: string;
    icon: null;
    integration: null;
    isReadOnly: boolean;
    isSearchable: boolean;
    isVirtual: false;
    onlyForRelationships: boolean;
    paginationType: 'page';
    actions: Array<ServequeryServerAction>;
    fields: Array<ServequeryServerField>;
    segments: Array<ServequeryServerSegment>;
};
export type ServequeryServerAction = {
    id: string;
    name: string;
    type: 'single' | 'bulk' | 'global';
    baseUrl: string;
    endpoint: string;
    httpMethod: 'POST';
    redirect: unknown;
    download: boolean;
    fields: ServequeryServerActionField[];
    hooks: {
        load: boolean;
        change: Array<unknown>;
    };
};
export type ServequeryServerActionFieldWidgetEditBase<TType = string, TConfig = unknown> = {
    name: TType;
    parameters: TConfig;
};
export type WidgetEditConfiguration = {
    name: string;
    parameters: Record<string, unknown>;
};
type ServequeryServerActionFieldType = ServequeryServerColumnType | 'File' | ['File'];
export type ServequeryServerActionFieldCommon<TType extends ServequeryServerActionFieldType = ServequeryServerActionFieldType, TWidgetEdit extends WidgetEditConfiguration | null = null> = {
    type: TType;
    value: unknown;
    defaultValue: unknown;
    description: string | null;
    field: string;
    hook: string;
    isReadOnly: boolean;
    isRequired: boolean;
    enums: null | string[];
    widgetEdit: TWidgetEdit;
};
export type ServequeryServerActionFieldBase = ServequeryServerActionFieldCommon & {
    reference: string | null;
};
type ServequeryServerActionFieldLimitedValueOptions<TName extends string, TValue = string, TParameters = Record<string, never>> = {
    name: TName;
    parameters: {
        static: {
            options: Array<{
                label: string;
                value: TValue;
            } | TValue>;
        };
    } & TParameters;
};
export type ServequeryServerActionFieldDropdownOptions<TValue = string> = ServequeryServerActionFieldLimitedValueOptions<'dropdown', TValue, {
    placeholder?: string | null;
    isSearchable?: boolean;
    searchType?: 'dynamic';
}>;
export type ServequeryServerActionFieldRadioButtonOptions<TValue = string> = ServequeryServerActionFieldLimitedValueOptions<'radio button', TValue>;
export type ServequeryServerActionFieldCheckboxGroupOptions<TValue = string> = ServequeryServerActionFieldLimitedValueOptions<'checkboxes', TValue>;
export type ServequeryServerActionFieldCheckboxOptions = {
    name: 'boolean editor';
    parameters: Record<string, never>;
};
export type ServequeryServerActionFieldTextInputOptions = {
    name: 'text editor';
    parameters: {
        placeholder?: string | null;
    };
};
export type ServequeryServerActionFieldAddressAutocompleteOptions = {
    name: 'address editor';
    parameters: {
        placeholder?: string | null;
    };
};
export type ServequeryServerActionFieldDatePickerInputOptions = {
    name: 'date editor';
    parameters: {
        format?: string | null;
        placeholder?: string | null;
        minDate?: string;
        maxDate?: string;
    };
};
export type ServequeryServerActionFieldTextInputListOptions = {
    name: 'input array';
    parameters: {
        placeholder?: string | null;
        enableReorder?: boolean;
        allowDuplicate?: boolean;
        allowEmptyValue?: boolean;
    };
};
export type ServequeryServerActionFieldTextAreaOptions = {
    name: 'text area editor';
    parameters: {
        placeholder?: string | null;
        rows?: number;
    };
};
export type ServequeryServerActionFieldRichTextOptions = {
    name: 'rich text';
    parameters: {
        placeholder?: string | null;
    };
};
export type ServequeryServerActionFieldTimePickerOptions = {
    name: 'time editor';
    parameters: Record<string, never>;
};
export type ServequeryServerActionFieldNumberInputOptions = {
    name: 'number input';
    parameters: {
        placeholder?: string | null;
        min?: number;
        max?: number;
        step?: number;
    };
};
export type ServequeryServerActionFieldNumberInputListOptions = {
    name: 'input array';
    parameters: {
        placeholder?: string | null;
        enableReorder?: boolean;
        allowDuplicate?: boolean;
        min?: number;
        max?: number;
        step?: number;
    };
};
export type ServequeryServerActionFieldColorPickerOptions = {
    name: 'color editor';
    parameters: {
        placeholder?: string | null;
        enableOpacity?: boolean;
        quickPalette?: string[];
    };
};
export type ServequeryServerActionFieldCurrencyInputOptions = {
    name: 'price editor';
    parameters: {
        placeholder?: string | null;
        min?: number;
        max?: number;
        step?: number;
        currency: string;
        base: 'Unit' | 'Cents';
    };
};
export type ServequeryServerActionFieldUserDropdown = {
    name: 'assignee editor';
    parameters: {
        placeholder?: string | null;
    };
};
export type ServequeryServerActionFieldJsonEditorOptions = {
    name: 'json code editor';
    parameters: Record<string, never>;
};
export type ServequeryServerActionFieldFilePickerOptions = {
    name: 'file picker';
    parameters: {
        prefix: null;
        filesCountLimit: number | null;
        filesExtensions: string[] | null;
        filesSizeLimit: number | null;
    };
};
export type ServequeryServerActionFieldDropdown = ServequeryServerActionFieldCommon<'String' | 'Dateonly' | 'Date' | 'Time', ServequeryServerActionFieldDropdownOptions<string>> | ServequeryServerActionFieldCommon<['String'], ServequeryServerActionFieldDropdownOptions<string[]>> | ServequeryServerActionFieldCommon<'Number', ServequeryServerActionFieldDropdownOptions<number>>;
export type ServequeryServerActionFieldRadioGroup = ServequeryServerActionFieldCommon<'String' | 'Dateonly' | 'Date' | 'Time', ServequeryServerActionFieldRadioButtonOptions<string>> | ServequeryServerActionFieldCommon<'Number', ServequeryServerActionFieldRadioButtonOptions<number>>;
export type ServequeryServerActionFieldCheckboxGroup = ServequeryServerActionFieldCommon<['String'], ServequeryServerActionFieldCheckboxGroupOptions<string>> | ServequeryServerActionFieldCommon<['Number'], ServequeryServerActionFieldCheckboxGroupOptions<number>>;
export type ServequeryServerActionField = ServequeryServerActionFieldDropdown | ServequeryServerActionFieldRadioGroup | ServequeryServerActionFieldCheckboxGroup | ServequeryServerActionFieldBase | ServequeryServerActionFieldCommon<'Boolean', ServequeryServerActionFieldCheckboxOptions> | ServequeryServerActionFieldCommon<'String', ServequeryServerActionFieldTextInputOptions> | ServequeryServerActionFieldCommon<'Date', ServequeryServerActionFieldDatePickerInputOptions> | ServequeryServerActionFieldCommon<['String'], ServequeryServerActionFieldTextInputListOptions> | ServequeryServerActionFieldCommon<'String', ServequeryServerActionFieldTextAreaOptions> | ServequeryServerActionFieldCommon<'String', ServequeryServerActionFieldUserDropdown> | ServequeryServerActionFieldCommon<'String', ServequeryServerActionFieldRichTextOptions> | ServequeryServerActionFieldCommon<'Time', ServequeryServerActionFieldTimePickerOptions> | ServequeryServerActionFieldCommon<'Number', ServequeryServerActionFieldNumberInputOptions> | ServequeryServerActionFieldCommon<'Number', ServequeryServerActionFieldCurrencyInputOptions> | ServequeryServerActionFieldCommon<['Number'], ServequeryServerActionFieldNumberInputListOptions> | ServequeryServerActionFieldCommon<'String', ServequeryServerActionFieldColorPickerOptions> | ServequeryServerActionFieldCommon<'File' | ['File'], ServequeryServerActionFieldFilePickerOptions> | ServequeryServerActionFieldCommon<'Json', ServequeryServerActionFieldJsonEditorOptions> | ServequeryServerActionFieldCommon<'String', ServequeryServerActionFieldAddressAutocompleteOptions>;
export type ServequeryServerField = Partial<{
    field: string;
    type: ServequeryServerColumnType;
    defaultValue: unknown;
    enums: null | string[];
    integration: null;
    isFilterable: boolean;
    isPrimaryKey: boolean;
    isReadOnly: boolean;
    isRequired: boolean;
    isSortable: boolean;
    isVirtual: boolean;
    reference: null | string;
    inverseOf: null | string;
    relationship: 'BelongsTo' | 'BelongsToMany' | 'HasMany' | 'HasOne';
    validations: Array<{
        message: string | null;
        type: ValidationType;
        value?: unknown;
    }>;
}>;
export type ServequeryServerSegment = {
    id: string;
    name: string;
};
export type ValidationType = 'contains' | 'is after' | 'is before' | 'is greater than' | 'is less than' | 'is like' | 'is longer than' | 'is present' | 'is shorter than';
export { };
//# sourceMappingURL=types.d.ts.map